@@ -65,10 +65,6 @@ impl PreprocessedMft {
         }
     }
 
-    pub fn entries_count(&self) -> usize {
-        self.complete_entries.len()
-    }
-
     pub fn bodyfile_lines_count(&self) -> usize {
         self.complete_entries.values().map(|e| e.bodyfile_lines_count()).sum()
     }
